#!/usr/bin/env python
# -*- coding: iso-8859-15 -*-h

############################################################
#
#      (c)   Jean-Matthieu Haussaire, Marc Bocquet
#      Programme l95grs_release.py
#      2014-2016
#
#      Supplementary material for:
#      J.-M. Haussaire and M. Bocquet
#      "A low-order coupled chemistry meteorology model
#      for testing online and offline data assimilation schemes:
#      L95-GRS (v1.0)"
#      published in Geophysical Model Development
#      doi:10.5194/gmd-9-393-2016
#  
#      Last change: 21/02/2015
#
############################################################


import numpy as np
import random, time
import matplotlib.pyplot as plt
import l95grs_release as model
from l95grs_release import Hybrid as scheme

Nt = 1000  # Number of time steps
Nts = 2000 # Number of time steps of the spinup

M = model.M
Dt = model.dt
G = model.G

x = model.NewState()

print("> spinup")

model.time = 0.

for t in range(Nts):
    scheme(x, Dt)
    model.time += Dt 

xr = np.empty([Nt,M]) 

# Trajectory
timeline = np.empty(Nt)
print("> main run")

tpr_beg = time.process_time()
twc_beg = time.perf_counter()

for t in range(Nt):
    print(t)
    scheme(x, Dt)
    model.time += Dt 
    timeline[t] = model.time
    xr[t] = x

tpr_end = time.process_time()
twc_end = time.perf_counter()

wctime = twc_end-twc_beg
prtime = tpr_end-tpr_beg
print("> wctime(s)", wctime, " prtime(s)", prtime)

print("> plot the run")
wind = xr[0:Nt,:G].T
tracer = xr[0:Nt,G:].T
print(wind.shape)


##  Convert Lorenz95 timeline into timeline in hours (1 Lorenz95 unit = 120h)
timeline = timeline*120.

# Plot spatial average concentrations
fig = plt.figure()
plt.subplot(321)
plt.plot(timeline, np.average(xr[0:Nt,0:G],axis=1))
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('Wind', fontsize = 8)
plt.subplot(322)
plt.plot(timeline, np.average(xr[0:Nt,G:2*G],axis=1))
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('ROC', fontsize = 8)
plt.subplot(323)
plt.plot(timeline, np.average(xr[0:Nt,2*G:3*G],axis=1))
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('NO', fontsize = 8)
plt.subplot(324)
plt.plot(timeline, np.average(xr[0:Nt,3*G:4*G],axis=1))
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('NO2', fontsize = 8)
plt.subplot(325)
plt.plot(timeline, np.average(xr[0:Nt,4*G:5*G],axis=1))
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('O3', fontsize = 8)
plt.subplot(326)
plt.plot(timeline, np.average(xr[0:Nt,5*G:6*G],axis=1))
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('SGN', fontsize = 8)
plt.savefig('run1.pdf')
plt.show()

# Plot concentrations at location specified by ind
fig = plt.figure()
ind = 0
plt.subplot(321)
plt.plot(timeline, xr[0:Nt,ind])
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('Wind', fontsize = 8)
plt.subplot(322)
plt.plot(timeline, xr[0:Nt,G+ind])
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('ROC', fontsize = 8)
plt.subplot(323)
plt.plot(timeline, xr[0:Nt,2*G+ind])
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('NO', fontsize = 8)
plt.subplot(324)
plt.plot(timeline, xr[0:Nt,3*G+ind])
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('NO2', fontsize = 8)
plt.subplot(325)
plt.plot(timeline, xr[0:Nt,4*G+ind])
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('O3', fontsize = 8)
plt.subplot(326)
plt.plot(timeline, xr[0:Nt,5*G+ind])
plt.tick_params(axis='both', which='major', labelsize=7)
plt.title('SGN', fontsize = 8)
plt.savefig('run2.pdf')
plt.show()
